package dev.kske.chess.ui;

import java.io.IOException;
import java.util.ArrayList;
import java.util.List;

import dev.kske.chess.uci.UCIHandle;
import dev.kske.chess.uci.UCIListener;

/**
 * Project: <strong>Chess</strong><br>
 * File: <strong>MenuBar.java</strong><br>
 * Created: <strong>23.07.2019</strong><br>
 * Author: <strong>Leon Hofmeister</strong>
 */
public class EngineUtil {

	private static volatile List<EngineInfo> engineInfos;

	static {
		engineInfos = new ArrayList<>();
	}

	private EngineUtil() {}

	public static void addEngine(String enginePath) {
			try {
				EngineInfo info = new EngineInfo(enginePath);
				UCIHandle handle = new UCIHandle(enginePath);
				handle.setListener(new UCIListener() {

					@Override
					public void onIdName(String name) {
						info.name = name;
					}

					@Override
					public void onIdAuthor(String author) {
						info.author = author;
					}
					
					@Override
					public void onUCIOk() {
						engineInfos.add(info);
						System.out.println("Engine: " + info.name);
					}
				});
				handle.start();
			} catch (IOException ex) {
				ex.printStackTrace();
			}
	}

	public static class EngineInfo {
		public String path, name, author;

		public EngineInfo(String path) {
			this.path = path;
		}
	}
}
